@@ -4,6 +4,18 @@ use strict;
 use Term::ShellUI;
 use Term::ANSIColor qw(:constants);
 
+=head1 NAME 
+
+OSGi::Osgish::Shell - Facade to Term::ShellUI
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 METHODS
+
+=cut
+
 sub new { 
     my $class = shift;
     my $self = ref($_[0]) eq "HASH" ? $_[0] : {  @_ };
@@ -104,12 +116,14 @@ sub _init {
                        package_imported_from => RED,
                        package_exported_to => RED,
                        bundle_id => RED,
+                       bundle_name => RED,
                        header_name => DARK . YELLOW,
                        header_value => ""
                       };
     my $theme_dark = { 
                       host => YELLOW,
                       bundle_id => RED,
+                      bundle_name => RED,                      
                       bundle_active => GREEN,
                       bundle_installed => RED,
                       bundle_resolved => YELLOW,
@@ -159,5 +173,45 @@ sub _init {
     }
 }
 
+sub readline {
+    my $self = shift;
+    my $term = $self->term;
+    return $term->{term}->ReadLine;
+}
+
+
+=head1 LICENSE
+
+This file is part of osgish.
+
+Osgish is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 2 of the License, or
+(at your option) any later version.
+
+osgish is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with osgish.  If not, see <http://www.gnu.org/licenses/>.
+
+A commercial license is available as well. Please contact roland@cpan.org for
+further details.
+
+=head1 PROFESSIONAL SERVICES
+
+Just in case you need professional support for this module (or JMX or OSGi in
+general), you might want to have a look at www.consol.com Contact
+roland.huss@consol.de for further information (or use the contact form at
+http://www.consol.com/contact/)
+
+=head1 AUTHOR
+
+roland@cpan.org
+
+=cut
 
 1;
+
